@@ -263,19 +263,6 @@ typedef Matrix_t<dcomplex>            zMatrix;
 typedef Matrix_map<double>            dMatrix_map;
 typedef Matrix_map< std::complex<double> > zMatrix_map;
 
-//
-// vector<Matrix>
-//
-template <typename C>
-std::vector<C> vector_matrix(int n,int I=1,int J=1){
-  std::vector<C> ret;
-  for(int i=0;i<n;i++){
-    C m(I,J);
-    ret.push_back(m);
-  }
-  return ret; 
-}
-
 //
 // copy
 //
