@@ -195,7 +195,6 @@ void Grid_Inte<M_tmpl,Integ1e>::set_rou_grid_for_PBC(str_Rou_pbc &ret_rou_pbc,co
   lc_1 = sqrt(T123[0*3+0]*T123[0*3+0]+T123[0*3+1]*T123[0*3+1]+T123[0*3+2]*T123[0*3+2]);
   lc_2 = sqrt(T123[1*3+0]*T123[1*3+0]+T123[1*3+1]*T123[1*3+1]+T123[1*3+2]*T123[1*3+2]);
   lc_3 = sqrt(T123[2*3+0]*T123[2*3+0]+T123[2*3+1]*T123[2*3+1]+T123[2*3+2]*T123[2*3+2]);
-
   
   //  cgtos_pbc
   std::vector<Shell_Cgto> tsc = Util_GTO::get_scgtos_PBC(scgtos, ctrl_pbc.get_max_Nc(), ctrl_pbc.get_T123() );
@@ -959,7 +958,7 @@ void Grid_Inte<M_tmpl,Integ1e>::grid_inte_sub_Matrix_PBC(double &ret_omp_ene, st
   int  g     =env.loop_g;
   int  a     =env.loop_a;
   double integ_w = env.integ_w;
-  std::vector<double> rou_deri(3, 0.0);
+  double rou_deri[3]={0.0};
 
   int an=(a%N_atoms)*Ng+g;
   double rou=str_rou_pbc.rou[an];
@@ -1027,6 +1026,8 @@ double Grid_Inte<M_tmpl,Integ1e>::grid_integral_base(std::vector<M_tmpl*> &ret_V
 
   if(functor.get_use_grid_inte()==0) return 0.0;
 
+
+
   // construct base-grid
   std::vector<double> xyzw_g;
   grid_data.get_grid(xyzw_g);
@@ -1042,13 +1043,16 @@ double Grid_Inte<M_tmpl,Integ1e>::grid_integral_base(std::vector<M_tmpl*> &ret_V
 
   // set rou_pbc 
   time_t start_t2,stop_t2;
-  time(&start_t2);
   str_Rou_pbc str_rou_pbc;
   if(mode_pbc==PBC && mode_unrestricted==RESTRICTED){
-    set_rou_grid_for_PBC(str_rou_pbc, scgtos, Da_PBC, Rxyz, ctrl_pbc, functor);
+    time(&start_t2);
+    // copy scgtos
+    std::vector<Shell_Cgto> cp_scgtos;
+    for(int i=0;i<scgtos.size();i++){  cp_scgtos.push_back(scgtos[i]);  cp_scgtos[i].set_dI<Integ1e>(); }
+    set_rou_grid_for_PBC(str_rou_pbc, cp_scgtos, Da_PBC, Rxyz, ctrl_pbc, functor);
+    time(&stop_t2);
+    if(process_num==0) std::cout<<"    time: "<<difftime(stop_t2,start_t2)<<std::endl;
   }
-  time(&stop_t2);
-  if(process_num==0) std::cout<<"  time: "<<difftime(stop_t2,start_t2)<<std::endl;
 
   //  preparation of cgtos
   std::vector<Shell_Cgto> tsc = Util_GTO::get_scgtos_PBC(scgtos, ctrl_pbc.get_max_Nc(), ctrl_pbc.get_T123() );
@@ -1132,14 +1136,12 @@ double Grid_Inte<M_tmpl,Integ1e>::grid_integral_base(std::vector<M_tmpl*> &ret_V
             if(mode_pbc==MOLECULE){  // molecule
               if(mode_unrestricted==RESTRICTED){
                 if(mode_grad==MATRIX){ 
-             //     grid_inte_sub_Matrix(omp_ene, ret_Vxc_a_PBC, Da_PBC, functor, env);
                   grid_inte_sub_Matrix(omp_ene, omp_Vxc_a_PBC, Da_PBC, functor, env);
                 }else{  // gradient
                   grid_inte_sub_grad(omp_grad, Da_PBC, functor, env);
                 }
               }else{  // unrestricted
                 if(mode_grad==MATRIX){ 
-              //    grid_inte_sub_Matrix_u(omp_ene, ret_Vxc_a_PBC, ret_Vxc_b_PBC, Da_PBC, Db_PBC, functor, env);
                   grid_inte_sub_Matrix_u(omp_ene, omp_Vxc_a_PBC, omp_Vxc_b_PBC, Da_PBC, Db_PBC, functor, env);
                 }else{  // gradient
                   grid_inte_sub_grad_u(omp_grad, Da_PBC, Db_PBC, functor, env);
@@ -1151,7 +1153,6 @@ double Grid_Inte<M_tmpl,Integ1e>::grid_integral_base(std::vector<M_tmpl*> &ret_V
                 if(mode_grad==MATRIX){
                   env.loop_a=a;
                   env.loop_g=g;
-               //   grid_inte_sub_Matrix_PBC(omp_ene, ret_Vxc_a_PBC, str_rou_pbc, Da_PBC, functor, ctrl_pbc, env);
                   grid_inte_sub_Matrix_PBC(omp_ene, omp_Vxc_a_PBC, str_rou_pbc, Da_PBC, functor, ctrl_pbc, env);
                 }else{
                   if(process_num==0) std::cout<<"  not implemneted yet "<<std::endl;
